==> odoo_14.0.0+dfsg.2.orig.tar.xz: odoo-14.0.0+dfsg.2/addons/website/README.md <==
Odoo Website Builder
--------------------

Get an awesome and <a href="https://www.odoo.com/page/website-builder">free website</a>,
easily customizable with the Odoo <a href="https://www.odoo.com/page/website-builder">website builder</a>.

Create enterprise grade website with our super easy builder. Use finely
designed building blocks and edit everything inline.

Benefit from out-of-the-box business features; e-Commerce, events, blogs, jobs
announces, customer references, call-to-actions, etc.

Edit Anything Inline
--------------------

Create beautiful websites with no technical knowledge. Odoo's unique *'edit
inline'* approach makes website creation surprisingly easy. No more complex
backend; just click anywhere to change any content.

"Want to change the price of a product? or put it in bold? Want to change a
blog title?" Just click and change. What you see is what you get. Really.

Awesome. Astonishingly Beautiful.
---------------------------------

Odoo's building blocks allow to design modern websites that are not possible
with traditional WYSIWYG page editors.

Whether it's for products descriptions, blogs or static pages, you don't need
to be a professional designer to create clean contents. Just drag and drop and
customize predefined building blocks.

Enterprise-Ready, out-of-the-box
--------------------------------

Activate ready-to-use enterprise features in just a click; e-commerce,
call-to-actions, jobs announces, events, customer references, blogs, etc.

Traditional eCommerce and CMS have poorly designed backends as it's not their
core focus. With the Odoo integration, you benefit from the best management
software to follow-up on your orders, your jobs applicants, your leads, etc.

A Great Mobile Experience
-------------------------

Get a mobile friendly website thanks to our responsive design based on
bootstrap. All your pages adapt automatically to the screen size. (mobile
phones, tablets, desktop) You don't have to worry about mobile contents, it
works by default.

SEO tools at your finger tips
-----------------------------

The *Promote* tool suggests keywords according to Google most searched terms.
Search Engine Optimization tools are ready to use, with no configuration
required.

Google Analytics tracks your shopping cart events by default. Sitemap and
structured content are created automatically for Google indexation.

Multi-Languages Made Easy
-------------------------

Get your website translated in multiple languages with no effort. Odoo proposes
and propagates translations automatically across pages, following what you edit
on the master page.

Designer-Friendly Templates
---------------------------

Templates are awesome and easy to design. You don't need to develop to create
new pages, themes or building blocks. We use a clean HTML structure, a
[bootstrap](http://getbootstrap.com/) CSS.

Customize every page on the fly with the integrated template editor. Distribute
your work easily as an Odoo module.

Fluid Grid Layouting
--------------------

Design perfect pages by drag and dropping building blocks. Move and scale them
to fit the layout you are looking for.

Building blocks are based on a responsive, mobile friendly fluid grid system
that appropriately scales up to 12 columns as the device or viewport size
increases.

Professional Themes
-------------------

Design a custom theme or reuse pre-defined themes to customize the look and
feel of your website.

Test new color scheme easily; you can change your theme at any time in just a
click.

Integrated With Odoo Apps
-------------------------

### e-Commerce

Promote products, sell online, optimize visitors' shopping experience.


### Blogs

Write news, attract new visitors, build customer loyalty.


### Online Events

Schedule, organize, promote or sell events online; conferences, trainings, webinars, etc.

==> odoo_18.0.0+dfsg.orig.tar.xz: odoo-18.0.0+dfsg/addons/website/README.md <==
Odoo Website Builder
--------------------

Get an awesome and <a href="https://www.odoo.com/app/website">free website</a>,
easily customizable with the Odoo <a href="https://www.odoo.com/app/website">website builder</a>.

Create enterprise grade website with our super easy builder. Use finely
designed building blocks and edit everything inline.

Benefit from out-of-the-box business features; e-Commerce, events, blogs, jobs
announces, customer references, call-to-actions, etc.

Edit Anything Inline
--------------------

Create beautiful websites with no technical knowledge. Odoo's unique *'edit
inline'* approach makes website creation surprisingly easy. No more complex
backend; just click anywhere to change any content.

"Want to change the price of a product? or put it in bold? Want to change a
blog title?" Just click and change. What you see is what you get. Really.

Awesome. Astonishingly Beautiful.
---------------------------------

Odoo's building blocks allow to design modern websites that are not possible
with traditional WYSIWYG page editors.

Whether it's for products descriptions, blogs or static pages, you don't need
to be a professional designer to create clean contents. Just drag and drop and
customize predefined building blocks.

Enterprise-Ready, out-of-the-box
--------------------------------

Activate ready-to-use enterprise features in just a click; e-commerce,
call-to-actions, jobs announces, events, customer references, blogs, etc.

Traditional eCommerce and CMS have poorly designed backends as it's not their
core focus. With the Odoo integration, you benefit from the best management
software to follow-up on your orders, your jobs applicants, your leads, etc.

A Great Mobile Experience
-------------------------

Get a mobile friendly website thanks to our responsive design based on
bootstrap. All your pages adapt automatically to the screen size. (mobile
phones, tablets, desktop) You don't have to worry about mobile contents, it
works by default.

SEO tools at your finger tips
-----------------------------

The *Promote* tool suggests keywords according to Google most searched terms.
Search Engine Optimization tools are ready to use, with no configuration
required.

Google Analytics tracks your shopping cart events by default. Sitemap and
structured content are created automatically for Google indexation.

Multi-Languages Made Easy
-------------------------

Get your website translated in multiple languages with no effort. Odoo proposes
and propagates translations automatically across pages, following what you edit
on the master page.

Designer-Friendly Templates
---------------------------

Templates are awesome and easy to design. You don't need to develop to create
new pages, themes or building blocks. We use a clean HTML structure, a
[bootstrap](http://getbootstrap.com/) CSS.

Customize every page on the fly with the integrated template editor. Distribute
your work easily as an Odoo module.

Fluid Grid Layouting
--------------------

Design perfect pages by drag and dropping building blocks. Move and scale them
to fit the layout you are looking for.

Building blocks are based on a responsive, mobile friendly fluid grid system
that appropriately scales up to 12 columns as the device or viewport size
increases.

Professional Themes
-------------------

Design a custom theme or reuse pre-defined themes to customize the look and
feel of your website.

Test new color scheme easily; you can change your theme at any time in just a
click.

Integrated With Odoo Apps
-------------------------

### e-Commerce

Promote products, sell online, optimize visitors' shopping experience.


### Blog

Write news, attract new visitors, build customer loyalty.


### Online Events

Schedule, organize, promote or sell events online; conferences, trainings, webinars, etc.
